.. vim: set fileencoding=utf-8 :
.. author: Manuel Günther <manuel.guenther@idiap.ch>
.. author: Pavel Korshunov <pavel.korshunov@idiap.ch>
.. date: Wed Apr 27 14:58:21 CEST 2016

.. This file contains all links we use for documentation in a centralized place

.. _idiap: http://www.idiap.ch
.. _github: http://www.github.com/idiap
.. _bob: http://www.idiap.ch/software/bob
.. _github bug reporting system: http://github.com/bioidiap/bob.pad.base/issues
.. _idiap at github: http://www.github.com/bioidiap
.. _bob's github page: http://idiap.github.com/bob
.. _buildout: http://www.buildout.org
.. _setuptools: http://trac.edgewall.org/wiki/setuptools
.. _nist: http://www.nist.gov/itl/iad/ig/focs.cfm
.. _pypi: http://pypi.python.org
.. _sge: http://wiki.idiap.ch/linux/SunGridEngine
.. _virtualbox: https://www.virtualbox.org
.. _hdf5: http://www.hdfgroup.org/HDF5
.. _bobinstall: https://www.idiap.ch/software/bob/install
.. _conda: https://conda.io
.. _sklearn-dev-docs: https://scikit-learn.org/dev/developers/develop.html#apis-of-scikit-learn-objects
.. _sklearn: https://scikit-learn.org
